summaryrefslogtreecommitdiff
path: root/slideshow/source/inc/slide.hxx
diff options
context:
space:
mode:
Diffstat (limited to 'slideshow/source/inc/slide.hxx')
-rw-r--r--slideshow/source/inc/slide.hxx7
1 files changed, 6 insertions, 1 deletions
diff --git a/slideshow/source/inc/slide.hxx b/slideshow/source/inc/slide.hxx
index 9f4e6b8f5055..d457d8e16f88 100644
--- a/slideshow/source/inc/slide.hxx
+++ b/slideshow/source/inc/slide.hxx
@@ -121,9 +121,14 @@ namespace slideshow
///Draw the slide Polygons
virtual void drawPolygons() const = 0;
///Check if slide is already active
virtual bool isPaintOverlayActive() const = 0;
+ virtual void enablePaintOverlay() = 0;
+ virtual void disablePaintOverlay() = 0;
+
+ virtual void update_settings( bool bUserPaintEnabled, RGBColor const& aUserPaintColor, double dUserPaintStrokeWidth ) = 0;
+
// Slide bitmaps
// -------------------------------------------------------------------
@@ -121,9 +121,14 @@ namespace slideshow
///Draw the slide Polygons
virtual void drawPolygons() const = 0;
- ///Check if slide is already active
+ ///Check if paint overlay is already active
virtual bool isPaintOverlayActive() const = 0;